<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Arsip';
$labels['buttontitle'] = 'Arsipkan pesan ini';
$labels['archived'] = 'Berhasil mengarsipkan';
$labels['archivedreload'] = 'Berhasil diarsipkan. Reload halaman untuk melihat folder arsip baru.';
$labels['archiveerror'] = 'Beberapa pesan tidak dapat diarsipkan';
$labels['archivefolder'] = 'Arsip';
$labels['settingstitle'] = 'Arsip';
$labels['archivetype'] = 'Pisah arsip berdasarkan';
$labels['archivetypeyear'] = 'Tahun (contoh: Arsip/2012)';
$labels['archivetypemonth'] = 'Bulan (contoh: Arsip/2012/06)';
$labels['archivetypetbmonth'] = 'Bulan - Kecocokan Thunderbird ( contoh: Arsip/2012/2012-06 )';
$labels['archivetypefolder'] = 'Folder asli';
$labels['archivetypesender'] = 'Email pengirim';
$labels['unkownsender'] = 'Tidak dikenal';
$labels['readonarchive'] = 'Tandai pesan telah dibaca di arsip';
