<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Vcard Attachments plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-vcard_attachments/
*/

$labels['addvcardmsg'] = 'افزودن vCard به دفترچه نشانی';
$labels['vcardsavefailed'] = 'ناتوان در ذخیره vCard';
