<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Vcard Attachments plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-vcard_attachments/
*/

$labels['addvcardmsg'] = 'Dodaj wizytówkę (vCard) do kontaktów';
$labels['vcardsavefailed'] = 'Nie można zapisać wizytówki (vCard)';
$labels['attachvcard'] = 'Dołącz plik vCard';
$labels['vcardattached'] = 'Załączono plik vCard.';
$labels['vcard'] = 'vCard';
$labels['forwardvcard'] = 'Prześlij vCard.';
$labels['contactsattached'] = 'Ta wiadomość posiada $num załączone kontakty.';
$labels['importedsuccessfully'] = 'Kontakt(y) zostały zaimportowane do książki adresowej.';
